@@ -5,7 +5,7 @@ package Net::SAML2::Binding::Redirect;
 use Moose;
 use MooseX::Types::URI qw/ Uri /;
 
-our $VERSION = '0.49';
+our $VERSION = '0.52';
 
 # ABSTRACT: Net::SAML2::Binding::Redirect - HTTP Redirect binding for SAML
 
@@ -17,7 +17,7 @@ use URI;
 use URI::QueryParam;
 use Crypt::OpenSSL::RSA;
 use Crypt::OpenSSL::X509;
-use File::Slurp qw/ read_file /;
+use File::Slurper qw/ read_text /;
 use URI::Encode qw/uri_decode/;
 
 
@@ -43,7 +43,7 @@ sub sign {
     $u->query_param($self->param, $req);
     $u->query_param('RelayState', $relaystate) if defined $relaystate;
 
-    my $key_string = read_file($self->key);
+    my $key_string = read_text($self->key);
     my $rsa_priv = Crypt::OpenSSL::RSA->new_private_key($key_string);
 
     if ( exists $self->{ sig_hash } && grep { $_ eq $self->{ sig_hash } } ('sha224', 'sha256', 'sha384', 'sha512'))
@@ -89,6 +89,19 @@ sub verify {
     my $saml_request;
     my $sig = $u->query_param_delete('Signature');
 
+    # During the verify the only query parameters that should be in the query are
+    # 'SAMLRequest', 'RelayState', 'Sig', 'SigAlg' the other parameter values are
+    # deleted from the URI query that was created from the URL that was passed
+    # to the verify function
+    my @signed_params = ('SAMLRequest', 'RelayState', 'Sig', 'SigAlg');
+
+    for my $key ($u->query_param) {
+        if (grep /$key/, @signed_params ) {
+            next;
+        }
+        $u->query_param_delete($key);
+    }
+
     # Some IdPs (PingIdentity) seem to double encode the LogoutResponse URL
     if (defined $self->sls_double_encoded_response and $self->sls_double_encoded_response == 1) {
         #if ($sigalg =~ m/%/) {
@@ -152,7 +165,7 @@ Net::SAML2::Binding::Redirect - Net::SAML2::Binding::Redirect - HTTP Redirect bi
 
 =head1 VERSION
 
-version 0.49
+version 0.52
 
 =head1 SYNOPSIS
 
@@ -247,7 +260,7 @@ Chris Andrews  <chrisa@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Chris Andrews and Others, see the git log.
+This software is copyright (c) 2022 by Chris Andrews and Others, see the git log.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
